import _JSXStyle from "styled-jsx/style";
import React from "react";
import { Button } from "@orbit-ui/react-button";
import { PureComponent, createRef } from "react";
import { bool, func, string } from "prop-types";
import { isNil } from "lodash";
export class DatePickerButtons extends PureComponent {
  constructor(...args) {
    super(...args);
    this._applyRef = createRef();

    this.handleClear = event => {
      const {
        canClear,
        onClear
      } = this.props;

      if (canClear) {
        onClear(event, this.props);
      } // Since clearing the date(s) will disabled the "clear" button we move the focus to the "apply" button.


      setTimeout(() => {
        if (!isNil(this._applyRef.current)) {
          this._applyRef.current.focus();
        }
      }, 0);
    };

    this.handleApply = event => {
      const {
        canApply,
        onApply
      } = this.props;

      if (canApply) {
        onApply(event, this.props);
      }
    };
  }

  renderClearButton() {
    const {
      canClear,
      allowClear,
      clearText
    } = this.props;

    if (!allowClear) {
      return null;
    } // Must used a CSS class to hide the button instead of conditional rendering otherwise clicking the button will be considered an outside click.


    return React.createElement(Button, {
      onClick: this.handleClear,
      ghost: true,
      compact: true,
      size: "small",
      disabled: !canClear,
      tabIndex: canClear ? "0" : "-1"
    }, clearText);
  }

  renderApplyButton() {
    const {
      canApply,
      applyText
    } = this.props;
    return (// Sadly, the div container is necessary to apply styled-jsx. Fragment doesn't work.
      React.createElement("div", {
        className: "jsx-1634713581" + " " + "container"
      }, React.createElement(Button, {
        onClick: this.handleApply,
        ghost: true,
        compact: true,
        primary: canApply,
        disabled: !canApply,
        size: "small",
        tabIndex: canApply ? "0" : "-1",
        ref: this._applyRef
      }, applyText), React.createElement(_JSXStyle, {
        id: "1634713581"
      }, [".container.jsx-1634713581{margin-left:auto;}"]))
    );
  }

  render() {
    const {
      className
    } = this.props;
    const defaultClasses = "flex ph6 pb6";
    const classes = isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
    return React.createElement("div", {
      className: classes
    }, this.renderClearButton(), this.renderApplyButton());
  }

}
DatePickerButtons.displayName = "DatePickerButtons";
DatePickerButtons.propTypes = {
  canClear: bool.isRequired,
  canApply: bool.isRequired,
  onClear: func,
  onApply: func,
  allowClear: bool,
  clearText: string,
  applyText: string,
  className: string
};
DatePickerButtons.defaultProps = {
  clearText: "Clear",
  applyText: "Apply"
};