import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Dropdown } from "semantic-ui-react";
import { DropdownContext } from "./context";
import { createIconForControl } from "@orbit-ui/react-icons";
import { element } from "prop-types";
import { isNil } from "lodash";
import { throwWhenUnsupportedPropIsProvided } from "@orbit-ui/react-components-shared";
import { useContext } from "react";
const UNSUPPORTED_PROPS = ["flag", "label"];
const propTypes = {
  icon: element
};
export function DropdownItem(props) {
  const {
    icon,
    children
  } = props,
        rest = _objectWithoutProperties(props, ["icon", "children"]);

  const context = useContext(DropdownContext);
  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-dropdown/item");

  const renderIcon = () => {
    if (!isNil(icon)) {
      return createIconForControl(icon, context.size);
    }
  };

  return React.createElement(Dropdown.Item, Object.assign({
    icon: renderIcon()
  }, rest), children);
}
DropdownItem.displayName = "DropdownItem";
DropdownItem.propTypes = propTypes;

DropdownItem.create = (_ref) => {
  let {
    content
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["content"]);

  return React.createElement(DropdownItem, rest, content);
};